@@ -40,7 +40,7 @@ class AsyncSearchClient(NamespacedClient):
         Deletes an async search by ID. If the search is still running, the search request
         will be cancelled. Otherwise, the saved search results are deleted.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/async-search.html>`_
 
         :param id: The async search ID
         """
@@ -82,7 +82,7 @@ class AsyncSearchClient(NamespacedClient):
         Retrieves the results of a previously submitted async search request given its
         ID.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/async-search.html>`_
 
         :param id: The async search ID
         :param keep_alive: Specify the time interval in which the results (partial or
@@ -131,7 +131,7 @@ class AsyncSearchClient(NamespacedClient):
         Retrieves the status of a previously submitted async search request given its
         ID.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/async-search.html>`_
 
         :param id: The async search ID
         """
@@ -199,6 +199,7 @@ class AsyncSearchClient(NamespacedClient):
             ]
         ] = None,
         explain: t.Optional[bool] = None,
+        ext: t.Optional[t.Mapping[str, t.Any]] = None,
         fields: t.Optional[
             t.Union[t.List[t.Mapping[str, t.Any]], t.Tuple[t.Mapping[str, t.Any], ...]]
         ] = None,
@@ -239,18 +240,7 @@ class AsyncSearchClient(NamespacedClient):
         ] = None,
         rest_total_hits_as_int: t.Optional[bool] = None,
         routing: t.Optional[str] = None,
-        runtime_mappings: t.Optional[
-            t.Mapping[
-                str,
-                t.Union[
-                    t.Mapping[str, t.Any],
-                    t.Union[
-                        t.List[t.Mapping[str, t.Any]],
-                        t.Tuple[t.Mapping[str, t.Any], ...],
-                    ],
-                ],
-            ]
-        ] = None,
+        runtime_mappings: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
         script_fields: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
         scroll: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         search_after: t.Optional[
@@ -305,7 +295,7 @@ class AsyncSearchClient(NamespacedClient):
         """
         Executes a search request asynchronously.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/async-search.html>`_
 
         :param index: A comma-separated list of index names to search; use `_all` or
             empty string to perform the operation on all indices
@@ -335,6 +325,7 @@ class AsyncSearchClient(NamespacedClient):
             that are open, closed or both.
         :param explain: If true, returns detailed information about score computation
             as part of a hit.
+        :param ext: Configuration of search extensions defined by Elasticsearch plugins.
         :param fields: Array of wildcard (*) patterns. The request returns values for
             field names matching these patterns in the hits.fields property of the response.
         :param from_: Starting document offset. By default, you cannot page through more
@@ -474,6 +465,8 @@ class AsyncSearchClient(NamespacedClient):
             __query["expand_wildcards"] = expand_wildcards
         if explain is not None:
             __body["explain"] = explain
+        if ext is not None:
+            __body["ext"] = ext
         if fields is not None:
             __body["fields"] = fields
         if filter_path is not None:
